package Giblog::Command::new_website;

use base 'Giblog::Command::new';

use strict;
use warnings;

1;

=encoding utf8

=head1 NAME

Giblog::Command::new_website - Website creating command

=head1 DESCRIPTION

L<Giblog::Command::new_website> is a command to create a website.

=head1 METHODS

L<Giblog::Command::new_website> inherits all methods from L<Giblog::Command::new> and
implements the following new ones.
